Python: module TileStache.Goodies.VecTiles.topojson

TileStache.Goodies.VecTiles.topojson | index

Modules
`` |  |
json |  |  |

Functions
`` |  | decode(file) `Stub function to decode a TopoJSON file into a list of features. Not currently implemented, modeled on geojson.decode().` diff_encode(line, transform) `Differentially encode a shapely linestring or ring.` encode(file, features, bounds, is_clipped) `Encode a list of (WKB, property dict) features into a TopoJSON stream. Also accept three-element tuples as features: (WKB, property dict, id). Geometries in the features list are assumed to be unprojected lon, lats. Bounds are given in geographic coordinates as (xmin, ymin, xmax, ymax).` get_tiles(names, config, coord) `Retrieve a list of named TopoJSON layer tiles from a TileStache config. Check integrity and compatibility of each, looking at known layers, correct JSON mime-types, "Topology" in the type attributes, and matching affine transformations.` get_transform(bounds, size=1024) `Return a TopoJSON transform dictionary and a point-transforming function. Size is the tile size in pixels and sets the implicit output resolution.` merge(file, names, config, coord) `Retrieve a list of TopoJSON tile responses and merge them into one. get_tiles() retrieves data and performs basic integrity checks.` update_arc_indexes(geometry, merged_arcs, old_arcs) `Updated geometry arc indexes, and add arcs to merged_arcs along the way. Arguments are modified in-place, and nothing is returned.`